@@ -1,7 +1,7 @@
 # ---------------------------------------------------------------------------------------------------------
-#  Copyright 2003-2009 by Alex Peeters [alex.peeters@citap.be]
+#  Copyright 2003-2010 by Alex Peeters [alex.peeters@citap.be]
 # ---------------------------------------------------------------------------------------------------------
-# 2009/mm/dd, v3.001.001, snmptt-3.001.001-v5.0.x.sql
+# 2010/01/05, v3.001.002, snmptt-3.001.002-v5.0.x.sql
 # ---------------------------------------------------------------------------------------------------------
 
 create database if not exists `snmptt`;
